# django-cities

## Place models and worldwide place data for Django

[![PyPI version](https://badge.fury.io/py/django-cities.svg)](https://badge.fury.io/py/django-cities) [![Build status](https://travis-ci.org/arthanson/django-cities-xtd.svg?branch=master)](https://travis-ci.org/arthanson/django-cities-xtd.svg?branch=master)

----

django-cities provides you with place related models (eg. Country, Region, City) and data (from [GeoNames](http://www.geonames.org/)) that can be used in your django projects.

This package officially supports all currently supported versions of Python/Django:

|      Python   | 3.12                | 3.13                  | 3.14                  |
| :------------ | ------------------- | --------------------- | --------------------- |
| Django 5.0    | :white_check_mark:  | :x:                   | :x:                   |
| Django 5.1    | :white_check_mark:  | :white_check_mark:    | :x:                   |
| Django 5.2    | :white_check_mark:  | :white_check_mark:    | :white_check_mark:    |
| Django 6.0    | :white_check_mark:  | :white_check_mark:    | :white_check_mark:    |

| Key                   |                                                                     |
| :-------------------: | :------------------------------------------------------------------ |
| :white_check_mark:    | Officially supported, tested, and passing                           |
| :large_blue_circle:   | Tested and passing, but not officially supported                    |
| :x:                   | Known incompatibilities                                             |

See some of the data in action at [city.io](http://city.io) and [country.io](http://country.io).

----

## Documentation

For detailed documentation, please visit: https://arthanson.github.io/django-cities-xtd/

- [Requirements](https://arthanson.github.io/django-cities-xtd/requirements)
- [Installation](https://arthanson.github.io/django-cities-xtd/installation)
- [Configuration](https://arthanson.github.io/django-cities-xtd/configuration)
- [Writing Plugins](https://arthanson.github.io/django-cities-xtd/writing-plugins)
- [Development](https://arthanson.github.io/django-cities-xtd/development)
- [Examples](https://arthanson.github.io/django-cities-xtd/examples)
- [Third Party Apps/Extensions](https://arthanson.github.io/django-cities-xtd/third-party-apps)
- [TODO](https://arthanson.github.io/django-cities-xtd/todo)
- [Notes](https://arthanson.github.io/django-cities-xtd/notes)
- [Running Tests](https://arthanson.github.io/django-cities-xtd/running-tests)
- [Release Notes](https://arthanson.github.io/django-cities-xtd/release-notes)
